@@ -2,34 +2,32 @@ from simple_logger.logger import get_logger
 import shlex
 import subprocess
 from pylero.exceptions import PyleroLibException
-
+from typing import Dict, List
 
 LOGGER = get_logger(name=__name__)
 
 
-def git_diff():
+def git_diff() -> str:
     data = subprocess.check_output(shlex.split("git diff HEAD^-1"))
-    data = data.decode("utf-8")
-    return data
+    return data.decode()
 
 
-def git_diff_lines():
-    diff = {}
+def git_diff_lines() -> Dict[str, List[str]]:
+    diff: Dict[str, List[str]] = {}
     for line in git_diff().splitlines():
         LOGGER.debug(line)
         if line.startswith("+"):
             diff.setdefault("added", []).append(line)
-
     return diff
 
 
 def validate_polarion_requirements(
-    polarion_test_ids,
-    polarion_project_id,
-):
+    polarion_test_ids: List[str],
+    polarion_project_id: str,
+) -> List[str]:
     from pylero.work_item import TestCase, Requirement
 
-    tests_with_missing_requirements = []
+    tests_with_missing_requirements: List[str] = []
 
     for _id in polarion_test_ids:
         has_req = False
